@@ -22,5 +22,5 @@ kNNdist <- function(x, k, ...) dbscan::kNN(x, k, sort = TRUE, ...)$dist
 kNNdistplot <- function(x, k = 4, ...) {
   kNNdist <- sort(kNNdist(x, k ,...))
   plot(sort(kNNdist), type="l", ylab=paste(k, "-NN distance", sep=""),
-    xlab = "Pointes (sample) sorted by distance")
+    xlab = "Points (sample) sorted by distance")
 }
